# -*- coding: utf-8 -*-

#----------------------------------------------------------------------
#     This file is part of OpenSynergy System
#
#     F I L E  N A M E:
#        Synergy.py
#     F U N C T I O N S:
#        This is the main module of OpenSynergy System
#     A U T H O R:
#        Sebastian Żurek, 22-10-2007
#     M O D I F I E D  B Y:
#        (add youtself here if you are modifing this file)
#
#     L I C E N S E
#
#     Copyright (C) 2007 Sebastian Żurek
#
#     This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------


import wx

# ----------------------------------------------------------------------------
# CustomTreeCtrl events and binding for handling them
# ----------------------------------------------------------------------------
wxCONTACT_SELECTED = wx.NewEventType()
CONTACT_SELECTED = wx.PyEventBinder(wxCONTACT_SELECTED, 1)

class ContactSelectedEvent(wx.PyCommandEvent):
    """ContactSelectedEvent is a special subclassing of wx.PyCommandEvent."""

    def __init__(self, evtType, id, cid = None, identifier = None, *args, **kwargs):
        """Default class constructor.

        For internal use: do not call it in your code!
        
        """
        super(ContactSelectedEvent,self).__init__(evtType, id,*args,**kwargs)

        self._cid = cid
        self._identifier = identifier

    def GetCID(self):
        """Return Contact IDentifier Number.

        CID is a primary key in contacts database table.
        """
        return self._cid

    def SetCID(self, cid):
        """Set Contacts IDentifier Number.

        CID is a primary key in contacts database table.
        """
        self._cid = cid

    def GetIdentifier(self):
        """Return contact's Identifier string.

        """
        return self._identifier

    def SetIdentifier(self, identifier):
        """Set contact's identifier string.

        """
        self._cid = identifier


class ContactChoice(wx.Panel):
	"""Client selector widget that can distinguish the clients types"""
	def __init__(self,*args,**kwargs):
		super(ContactChoice,self).__init__(*args,**kwargs)
		#sizer=wx.BoxSizer(wx.VERTICAL)
                sizer=wx.StaticBoxSizer(wx.StaticBox(self,1,u"Wybierz Klienta"),wx.VERTICAL)

		self._data={}
		sampleList = ['Podmioty Gospodarcze','Osoby Fizyczne']
		self.rb = wx.RadioBox(
			self, -1, u"", (-1,-1), (-1,-1),
			sampleList, 2, wx.RA_SPECIFY_ROWS|wx.NO_BORDER
			)
		self.Bind(wx.EVT_RADIOBOX, self._onFilterChange, self.rb)
		self.rb.SetToolTip(wx.ToolTip("Wybierz filtr..."))
		sizer.Add(self.rb,0,wx.EXPAND)
		self.Choice=wx.Choice(self,-1,choices=[])
		sizer.Add(self.Choice,0,wx.GROW|wx.TOP,border=0)
		self.Bind(wx.EVT_CHOICE,self._onChoice)
		self.SetSizer(sizer)


	def SetModel(self,model):
		self._model=model
		self._SetData()
                self._ShowGospodarcze()
		
	def _SetData(self):
		self._data['fizyczne']=self._model.GetClientsWithType(1)
		self._data['gospodarcze']=self._model.GetClientsWithType(0)
                

	def _ShowGospodarcze(self):
		self.Choice.Clear()
		choic=[]
		for firm in self._data['gospodarcze']:
			self.Choice.Append(firm['identifier'],firm['cid'])
		self.Choice.SetSelection(0)
		self._filter='gospodarcze'
		if not self._data['gospodarcze']:
			self.Choice.Clear()
			self.Choice.Append(u'Brak Klientów')
			self.Choice.Disable()
		else:
			if not self.Choice.IsEnabled():
				self.Choice.Enable(True)
		evt=wx.CommandEvent(wx.wxEVT_COMMAND_CHOICE_SELECTED,self.Choice.GetId())
		self.GetEventHandler().ProcessEvent(evt)

	def _ShowFizyczne(self):
		self.Choice.Clear()
		choic=[]
		for firm in self._data['fizyczne']:
			self.Choice.Append(firm['identifier'],firm['cid'])
		self.Choice.SetSelection(0)
		self._filter='fizyczne'

		if not self._data['fizyczne']:
			self.Choice.Disable()
			self.Choice.Clear()
			self.Choice.Append(u'Brak Klientów')
		else:
			if not self.Choice.IsEnabled():
				self.Choice.Enable(True)
		evt=wx.CommandEvent(wx.wxEVT_COMMAND_CHOICE_SELECTED,self.Choice.GetId())
		self.GetEventHandler().ProcessEvent(evt)

	def _onFilterChange(self,evt):
		functions={'Podmioty Gospodarcze':self._ShowGospodarcze,'Osoby Fizyczne':self._ShowFizyczne}		
		functions[evt.GetString()]()


	def _onChoice(self,evt):
		evt.Skip()
                #print 'Wybrano czoica',
                #event=ContactSelectedEvent(wxCONTACT_SELECTED, self.GetId(),cid=evt.GetClientData())
                # TO DO: check why the evt.GetClientData() does not work when progamable event is sent
                event=ContactSelectedEvent(wxCONTACT_SELECTED, self.GetId(),cid=self.Choice.GetClientData(evt.GetSelection()))
		self.GetEventHandler().ProcessEvent(event)
		#print evt.GetClientData()
