# -*- coding: utf-8 -*-

#----------------------------------------------------------------------
#     This file is part of OpenSynergy System
#
#     F I L E  N A M E:
#        ContactsTree.py
#     F U N C T I O N S:
#        This file handles windows used by Contacts components
#     A U T H O R:
#        Grzegorz Hoszko
#     M O D I F I E D  B Y:
#        Sebastian Żurek
#
#     L I C E N S E
#
#     Copyright (C) 2008 Grzegorz Hoszko
#     Copyright (C) 2008 Sebastian Żurek
#
#     This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------

import wx
import wx.lib.pubsub as pubsub
import wx.lib.customtreectrl as CT
from ..KlienciModel import KlienciModel

class ContactsTree(CT.CustomTreeCtrl):
    def __init__(self, *args, **kwargs):
	super(ContactsTree, self).__init__(style=wx.SUNKEN_BORDER|CT.TR_HAS_BUTTONS|CT.TR_HIDE_ROOT|CT.TR_TWIST_BUTTONS, *args, **kwargs)

        # This widget it tightly bind to model - it renders the database contacts structure
        # to be nicely visualized. It used to use 'SetModel' method, but I've decided that it should
        # rather be hardcoded to a proper model - the only one model that will work with that widget
        # 12-08-2008 by SebZur
	self._model=KlienciModel()

        # The currently selected contact:
        self._currentContact = None
        
        # When the model is binded, we show the data:
        self.ShowContacts()

	self.Bind(CT.EVT_TREE_ITEM_RIGHT_CLICK, self.OnItemRightClick)
        self.Bind(CT.EVT_TREE_SEL_CHANGED, self.OnContactChanged)



    def ShowContacts(self,search = '', group = None):
        self.DeleteAllItems()
        contacts = self._model.GetContacts(search = search, group = group, children = True, basic=True, address=True, contact=True, invoice=True)
        self.root = self.AddRoot('Kontakty')
        for contact in contacts:
            parent = self.AppendItem(self.root, "%s (%s)"%(contact.GetFullName(),contact.GetIdentifier()))
            self.SetPyData(parent, contact)
            self.SetItemBold(parent, True)
            self.LoadChildren(parent,contact)


    def LoadChildren(self, node,parent):
        if parent.GetChildCount()==0:
            return
        else:
            for kid in parent.GetChildren():
                child = self.AppendItem(node, kid.GetIdentifier())
                self.SetPyData(child, kid)
                #self.SetItemBold(child, True)
                #self.SetItemImage(child, 0, CT.TreeItemIcon_Normal)
                #self.SetItemImage(child, 1, CT.TreeItemIcon_Expanded)
                self.LoadChildren(child,kid)
        
    
    def OnItemRightClick(self, event):
        if not hasattr(self, "popupID1"):
            self.popupID1 = wx.NewId()
            self.Bind(wx.EVT_MENU, self.OnModifyData, id=self.popupID1)
        #if not hasattr(self, "popupID2"):
    	#    self.popupID2 = wx.NewId()
    	#   self.Bind(wx.EVT_MENU, self.OnSendEmail, id=self.popupID2)
        if not hasattr(self, "popupID3"):
    	    self.popupID3 = wx.NewId()
    	    self.Bind(wx.EVT_MENU, self.OnDelClient, id=self.popupID3)

        menu = wx.Menu()
        menu.Append(self.popupID1, u"Modyfikuj dane")
        #menu.Append(self.popupID2, u"Wyslij email")
        menu.Append(self.popupID3, u"Usun klienta")
        self.PopupMenu(menu)
        menu.Destroy()
        
    def OnModifyData(self, event):
	item = self.GetSelection()
	client  = self.GetPyData(item)
	data = ('UpdateClient', client,)
	pubsub.Publisher().sendMessage("Clients.Events.Dialog", data=data)

    
    def OnSendEmail(self, event):
	print 'Wysylanie emaili'

    def OnDelClient(self, event):
	print 'Usuwanie klientow'

    def OnContactChanged(self, event):
        self._currentContact = event.GetItem()
        event.Skip()

    def GetCurrentContact(self):
        return self._currentContact

	
