# -*- coding: utf-8 -*-
import wx

from Synergy.Components.Share.Share import StaticSizerWithDifferentControls
from Synergy import Exceptions
from NIP_REGON import NIPValidator, REGONValidator
import wx.lib.masked as masked
from ..KlienciModel import Contact

class ContactDataField:
	def __init__(self,parent=None, style = 'edit'):		

		self._ctrls={}				
		self._sizer=wx.BoxSizer(wx.VERTICAL)
		self.parent=parent
		self.style = style
		self._createClientDataField(self._sizer,parent, style)

	def _editRepresentation(self):
		regs='\d{3}-\d{3}-\d{2}-\d{2}'
		typy_kontaktu = ['Zwykły','Gospodarcze','Fizyczne']

		return  {
			'full_name':wx.TextCtrl(self.parent,-1,'',name = u'Pełna nazwa:'),
			'identifier':wx.TextCtrl(self.parent,-1,'', name = 'Identyfikator:'),
			'grouping': wx.Choice(self.parent, -1, choices =  typy_kontaktu, name = 'Typ kontaktu:'),
			'nip':masked.TextCtrl(self.parent, -1, "",mask = "#{3}-#{3}-#{2}-#{2}",formatcodes='^',validRegex   = regs, name = 'NIP:'),
			'regon':wx.TextCtrl(self.parent,-1,'',name = 'Regon:'),
			'bank_name': wx.TextCtrl(self.parent,-1,'',name = 'Nazwa Banku:') ,
			'bank_account':wx.TextCtrl(self.parent,-1,'', name = 'Nr Konta:'),
			'city':wx.TextCtrl(self.parent,-1,'',name = 'Miasto:'),
			'zip': wx.TextCtrl(self.parent,-1,'',name = 'Kod pocztowy:'),
			'post':wx.TextCtrl(self.parent,-1,'',name = 'Poczta:'),
			'address':wx.TextCtrl(self.parent,-1,'',name = 'Adres:'),
			'email':wx.TextCtrl(self.parent,-1,'',name = 'E-mail:'),
			'tel':wx.TextCtrl(self.parent,-1,'',name = 'Telefon:'),
			'website':wx.TextCtrl(self.parent,-1,'',name = 'Strona WWW:'),
			}


	def _viewRepresentation(self):
		return {
			'full_name':wx.StaticText(self.parent,-1,'a',name = u'Pełna nazwa:'),
			'identifier':wx.StaticText(self.parent,-1, 'a',name = 'Identyfikator:'),
			'grouping': wx.StaticText(self.parent,-1, 'a',name = 'Typ Kontaktu:'),
			'nip':wx.StaticText(self.parent,-1, 'a',name = 'NIP:'),
			'regon':wx.StaticText(self.parent,-1,'a',name = 'Regon:'),
			'bank_name': wx.StaticText(self.parent,-1,'a', name = 'Nazwa Banku:') ,
			'bank_account':wx.StaticText(self.parent,-1,'a', name ='Nr Konta:'),
			'city':wx.StaticText(self.parent,-1,'a', name = 'Miasto:'),
			'zip': wx.StaticText(self.parent,-1,'a', name = 'Kod pocztowy:'),
			'post':wx.StaticText(self.parent,-1,'a', name = 'Poczta:'),
			'address':wx.StaticText(self.parent,-1,'a', name = 'Adres:'),
			'email':wx.StaticText(self.parent,-1,'a', name = 'E-mail:'),
			'tel':wx.StaticText(self.parent,-1,'a', name = 'Telefon:'),
			'website':wx.StaticText(self.parent,-1,'a', name = 'Strona WWW:'),
			}


	def _titleStaticLine(self,title,sizer):
		line = wx.StaticLine(self.parent,-1)
		title = wx.StaticText(self.parent,-1,title)
		f=wx.Font(10, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD,faceName='Nimbus Sans L')
		title.SetFont(f)
		s = wx.BoxSizer(wx.HORIZONTAL)
		s.Add(title,0,wx.GROW|wx.RIGHT,border = 5)
		s.Add(line,1,wx.GROW)
		sizer.AddSizer(s,0,wx.GROW|wx.LEFT|wx.RIGHT|wx.TOP|wx.BOTTOM,border = 10)

	def _createClientDataField(self, sizer, parent, style):
		""" Creates name, surname, logins and pass fields and add them to the
		sizer        
		
		"""

		
		# We will layout the client data goroups using 2x2 grid
		sizers = {'main': wx.BoxSizer(wx.HORIZONTAL),
			  'left': wx.BoxSizer(wx.VERTICAL),
			  'right': wx.BoxSizer(wx.VERTICAL)
			  }

		# Adding side sizer to main sizer
		sizers['main'].AddSizer(sizers['left'],1,wx.GROW)
		sizers['main'].AddSizer(sizers['right'],1,wx.GROW)

		# And adding the main sizer to the super sizer (which comes as the method argument)
		sizer.AddSizer(sizers['main'],1,wx.GROW)

		
                # This is required by the masked text control used to handle NIP nuber eneter
		groups=({'group':'Dane podstawowe',
			 'side': 'left',
			 'elements':('full_name','identifier','grouping')
			 },
			{'group':'Dane fakturowe',
			 'side': 'left',
			 'elements':('nip','regon','bank_name','bank_account'),
			 },
			{'group':'Dane adresowe',
			 'side': 'right',
			 'elements':('city','zip','post','address'),
			 },
			{'group':'Dane kontaktowe',
			 'side': 'right',
			 'elements':('email','tel','website')
			 },
			)


		# Font styles for labels and details of contacts
		labelFont = wx.Font(11, wx.ITALIC, wx.NORMAL, wx.NORMAL)
		detailsFont = wx.Font(12, wx.SWISS, wx.ITALIC, wx.NORMAL)

		# And populating GridSizer with elements, depending on style
		if style == 'view':
			self._ctrls = self._viewRepresentation()
		elif style == 'edit':
			self._ctrls = self._editRepresentation()
		for group in groups:
			# First, creating a group header:
			self._titleStaticLine(group['group'],sizers[group['side']])
			
			# Creating two-column GridSizer to layout elements label: value
			# inside the group:			
			fgs = wx.FlexGridSizer(rows=0, cols=2, hgap=10, vgap=10)
			fgs.AddGrowableCol(1,1)

			for element in group['elements']:
				# First, an item label
				label = wx.StaticText(self.parent,-1,self._ctrls[element].GetName())
				label.SetFont(labelFont)
				label.SetForegroundColour('#131de1')
				fgs.AddWindow(label)
				# Next, element to visualize the contact data
				#self._ctrls[element] = wx.StaticText(self.parent,-1,'dd')
				fgs.AddWindow(self._ctrls[element],1,wx.GROW)
				self._ctrls[element].SetFont(detailsFont)

			# Adding that GridSizer to side-sizer
			sizers[group['side']].AddSizer(fgs,1,wx.GROW|wx.RIGHT|wx.LEFT,10)
				

        def ShowContact(self,contact):
		"""Shows contact data.

		Keyword arguments:
		- identfier: a contact unique identifier required for the database query

		"""

		# Each contact data is a dictionary, so I can iterate on through it
		# to display results


		# Next, depending on the style choosen (edit or view) I show the data.
		# The widgets may use different Set/Get methods.
		if self.style == 'edit':
			self._ShowDataForEdit(contact)
		elif self.style == 'view':
			self._ShowDataForView(contact)

	def _ShowDataForEdit(self,data):
		# First, I'm getting keys in dictionary holding the widgets responsible for
		# visualisation:
		supportedKeys=self._ctrls.keys()
		for k in supportedKeys:                            
                            if k=='grouping':					
                                self._ctrls[k].SetSelection(data[k])
                            else:
                                self._ctrls[k].SetValue(data[k])

	def _ShowDataForView(self,contact):
		# First, I'm getting keys in dictionary holding the widgets responsible for
		# visualisation:
		supportedKeys=self._ctrls.keys()
		for k in supportedKeys:
			print k,contact.GetData()[k]
			self._ctrls[k].SetLabel(contact.GetData()[k])


	def DataValidator(self,data):
		if not (data['full_name'] and data['identifier'] and data['city'] and data['zip'] and data['post'] and data['address']):
			raise Exceptions.EmptyData(u'Musisz podać przynajmniej Pełną Nazwę, Identyfikator, Dane Adresowe oraz NIP Klienta.')
		elif data['nip'] and data['grouping'] in (1,2):
			NIPValidator.NIPValidator(data['nip'])
		elif data['regon']:
			REGONValidator.REGONValidator(data['regon'])
			raise Exceptions.EmptyData(u'Musisz wypełnić wszystkie pola')
		
	def GetData(self):
		""" Reads alternated user data and returns it in dictionary

		"""
		reads={}		
		for k in self._ctrls.keys():
			if k=='grouping':
				reads[k]=self._ctrls[k].GetSelection()
			elif k=='nip':
				reads[k]=self._ctrls[k].GetValue().replace('-','')
			else:
				reads[k]=self._ctrls[k].GetValue()

		self.DataValidator(reads)
		
		return Contact(data = reads)


	def GetSizer(self):
		return self._sizer

