# -*- coding: utf-8 -*-

#----------------------------------------------------------------------
#     This file is part of OpenSynergy System
#
#     F I L E  N A M E:
#        Windows.py
#     F U N C T I O N S:
#        This file handles windows used by Contacts components
#     A U T H O R:
#        Sebastian Żurek, sebzur@gmail.com, 02-02-2008
#     M O D I F I E D  B Y:
#        Grzegorz Hoszko
#
#     L I C E N S E
#
#     Copyright (C) 2007 Sebastian Żurek
#
#     This program is free software: you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation, either version 3 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------

import wx
import wx.lib.pubsub as pubsub
import wx.lib.customtreectrl as CT

from Synergy.Components.Share.Share import CommonPanel
from Synergy.Components.Users.Share import AccessSettingsPanel  as AccessSettingsPanel
from Synergy.Components.Users.Share import UserListBox as UserListBox
from Synergy  import Model
from Synergy.Visual import VisualToolBar
from Synergy import Preferences
default_encoding = Preferences.default_encoding

import string
import sys
import toolbarImages
import ContactsTree
from DataFields import ContactDataField

from wx.lib.art import img2pyartprov

class ConfigPanelAccessSetting(AccessSettingsPanel):
	def __init__(self,*args,**kwargs):				
		super(ConfigPanelAccessSetting,self).__init__(*args,**kwargs)

	def GetCols(self):
		return 2

	def GetLabels(self):
		labels=((u'Może przeglądać klientów','view_clients'),
			(u'Może modyfikować klientów','modify_clients')
			)
		return labels

	def GetFieldName(self):
		return u'Ustawienia dotępu'

                                                                                           
class DataPanelContacts(CommonPanel):
	def __init__(self,parent,*args,**kwargs):
		super(DataPanelContacts,self).__init__(parent=parent,name="Kontakty",dbAccessColumn='view_clients',*args,**kwargs)
		self._currentContact = None
		self._init_ctrls(parent)
		self._Subscribe()
		
	def _Subscribe(self):		
		pubsub.Publisher().subscribe(self.OnEvent, "Toolbar.Events.Clients")
		pubsub.Publisher().subscribe(self.OnEvent, "Model.Events")
		pubsub.Publisher().subscribe(self.OnEvent, "Contacts.Model.Events")


        def OnFlat(self,message):
                self.list.Refresh()

	def OnEvent(self,message):
		if hasattr(self,message.data[0]):
			getattr(self,message.data[0])(*message.data[1:])
		
	def NewContact(self,*args):
		self.clTree.ShowContacts()

	def OnSearch(self,txt):
	    print txt
#		self.list.GetDataSource().FilterData('surname',meassage.data)
#                self.list.Refresh() #Windows
	
	def OnItemSelected(self, event):
		item = event.GetItem()
		self._currentContact = self.clTree.GetPyData(item)		
		self._ctrls['contact_info'].ShowContact(self._currentContact)
		
			
	# Left panel with options and the tree of contacts
	def _createLeftPanel(self, sizerLeft, parent):
		podmiot = ['Wszystkie kontakty', 'Podmioty Gospodarcze', 'Osoby Fizyczne']
		checkBoxList = wx.CheckListBox(self, -1, wx.DefaultPosition, (315,70), podmiot)
		
		sizerLeft.Add(checkBoxList, 0, wx.ALL, border = 10)

		self.clTree = ContactsTree.ContactsTree(parent=parent)
		
		self.Bind(ContactsTree.CT.EVT_TREE_SEL_CHANGED, self.OnItemSelected, self.clTree)
		
		sizerLeft.Add(self.clTree, 1, wx.EXPAND|wx.ALL, border = 10)
		
		self.searchTxtCtrl = wx.SearchCtrl(self, -1, size = (305, 25))
		self.searchTxtCtrl.SetDescriptiveText(u'Poszukiwana fraza')
		staticBox = wx.StaticBox(self, 1, u'Wyszukiwanie')
		searchSizerStat = wx.StaticBoxSizer(staticBox, wx.VERTICAL)
		searchSizerStat.Add(self.searchTxtCtrl, 1, wx.GROW)

		sizerLeft.Add(searchSizerStat, 0, wx.GROW|wx.ALL, border = 10)
		

	# Right panel with details of contacts and additional options
	def _createRightPanel(self, sizerRight, parent):
		self._ctrls['contact_info'] = ContactDataField(self,style = 'view')
		
		detailsSizerStat = wx.StaticBoxSizer(wx.StaticBox(self, 1, u'Szczegolowe dane kontaktu'), wx.VERTICAL)
		detailsSizerStat.Add(self._ctrls['contact_info'].GetSizer(), 1, wx.GROW)
		self.sizerRight.Add(detailsSizerStat, 1, wx.EXPAND|wx.ALL, border = 10)

		self._initButtons(self.sizerRight)

	def _initButtons(self,sizer):

		# The buttons are layed out in static sizer:
		optionsSizerStat = wx.StaticBoxSizer(wx.StaticBox(self, 0, u'Opcje'), wx.HORIZONTAL)
		
		# We *do not* use explicit size and positions of buttons - they are layed out by
		# sizers
		buttons = (('Dodaj kontakt', self._OnNewContact, 'Dodawanie nowego kontaktu do bazy danych'),
			   ('Edytuj kontakt', self._OnEditContact, 'Modyfikacja szczegowych danych kontaktu'),
			   (u'Usuń kontakt', self._OnRemoveContact, 'Fizyczne usunicie kontaktu z bazy danych'),
			   (u'Dodaj powiązany kontakt', self._OnChildContact, 'Dodawanie do bazy danych nowego kontaktu powizanego')
			  )
		for button in buttons:
			bt = wx.Button(self, -1, button[0])
			optionsSizerStat.Add(bt, 1,wx.LEFT,border = 10)
			if button[1]!=None:
				self.Bind(wx.EVT_BUTTON,button[1],bt)
				bt.SetToolTip(wx.ToolTip(button[2]))
				  

		# We attache static sizer to main sizer (which comes as method argument):
		sizer.Add(optionsSizerStat, 0, wx.EXPAND|wx.ALL, border = 10)		

	def _OnNewContact(self,event):
		data=('NewContact',)
		pubsub.Publisher().sendMessage("Contacts.Events.Dialog",data=data)

	def _OnChildContact(self,event):
		print self._currentContact
		data=('NewContact',self._currentContact)
		pubsub.Publisher().sendMessage("Contacts.Events.Dialog",data=data)

	# Modifying data of selected contact
	def _OnEditContact(self, event):
		print 'Edycja'
		
	# Removing current contact from the database	
	def _OnRemoveContact(self, event):
		contactID = self._currentContact.GetIdentifier()
		remMsgDlg = wx.MessageDialog(self, 'Czy na pewno usun kontakt: ' + str(contactID) + '?', 'Pytanie', wx.YES_NO|wx.NO_DEFAULT|wx.ICON_QUESTION)
		if remMsgDlg.ShowModal() == wx.ID_YES:
			self._currentContact.Remove()
			self.clTree.ShowContacts()
		remMsgDlg.Destroy()

	def _init_ctrls(self, parent):			
		sizerMain = wx.BoxSizer(wx.HORIZONTAL)
		sizerLeft = wx.BoxSizer(wx.VERTICAL)
		self.sizerRight = wx.BoxSizer(wx.VERTICAL)
		self._ctrls={}
		
		self._createLeftPanel(sizerLeft, self)
		self._createRightPanel(self.sizerRight, self)
		
		sizerMain.Add(sizerLeft, 0, wx.EXPAND, border = 10)
		sizerMain.Add(self.sizerRight, 1, wx.EXPAND, border = 10)
		
		self.SetSizer(sizerMain)
		self.SetAutoLayout(True)


